Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.PersonSchlank Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.PersonSchlank einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.PersonSchlank) | Gemeinde_Modelle.PersonSchlank |
__str__(self) (Definiert in Gemeinde_Modelle.PersonSchlank) | Gemeinde_Modelle.PersonSchlank |
keyFeldNavi (Definiert in Gemeinde_Modelle.PersonSchlank) | Gemeinde_Modelle.PersonSchlank | static
R_anrede (Definiert in Gemeinde_Modelle.PersonSchlank) | Gemeinde_Modelle.PersonSchlank | static